import Button from '@mui/material/Button';
import { createTheme } from '@mui/material/styles';
import { render } from '@testing-library/react';

import NextGenThemeProvider from '../NextGenThemeProvider';

describe('NuskinThemeProvider', () => {
    const theme = createTheme({
        palette: {
            primary: {
                main: '#f00',
            },
        },
    });
    const commonText = 'Nu Skin App';
    it('1. renders without crashing', () => {
        const { getByText } = render(
            <NextGenThemeProvider theme={theme}>
                <div>{commonText}</div>
            </NextGenThemeProvider>,
        );
        expect(getByText(commonText)).toBeInTheDocument();
    });

    it('2. applies the correct theme to ThemeProvider', () => {
        const { getByText } = render(
            <NextGenThemeProvider theme={theme}>
                <Button variant="contained">{commonText}</Button>
            </NextGenThemeProvider>,
        );
        const comp = getByText(commonText);
        expect(comp).toHaveStyle('background-color: rgb(178, 0, 0)');
    });

    it('3. applies the correct theme to ThemeProvider with SSR', () => {
        const { getByText } = render(
            <NextGenThemeProvider theme={theme} isSSR>
                <Button variant="contained">{commonText}</Button>
            </NextGenThemeProvider>,
        );
        const comp = getByText(commonText);
        expect(comp).toHaveStyle('background-color: rgb(178, 0, 0)');
    });
});
