import { sortedLight } from '../fixtures/sortedLight';
import { createBaseColorsFromGroup, createColorGroups, createFromLightDarkBase, mixColors } from '../util';

describe('util - mixColors', () => {
    it('1. should create a palette object with 10 keys when base and initial are not empty', () => {
        const base = {
            N100: '#252525',
            N90: '#121212',
            N80: '#383838',
            N70: '#5F5F5F',
            N60: '#8C8C8C',
            N50: '#B2B2B2',
            N40: '#E0E0E0',
            N30: '#EDEDED',
            N20: '#F5F5F5',
            N10: '#FFFFFF',
        };

        const initial = 'N';
        const result = mixColors(base, initial);
        expect(Object.keys(result).length).toBe(10);
    });
});
describe('util - createColorGroups', () => {
    it('1. should correctly group colors based on middle group name', () => {
        const colorObjects = [
            { name: 'Primary/Neutral/Primary' },
            { name: 'Secondary/Info/Secondary' },
            { name: 'Warning/Neutral/Warning' },
            { name: 'Primary/Info/Primary' },
            { name: 'Secondary/Neutral/Secondary' },
            { name: 'Warning/Info/Warning' },
        ];
        const expectedColorMap = {
            Neutral: [
                { name: 'Primary/Neutral/Primary' },
                { name: 'Warning/Neutral/Warning' },
                { name: 'Secondary/Neutral/Secondary' },
            ],
            Info: [
                { name: 'Secondary/Info/Secondary' },
                { name: 'Primary/Info/Primary' },
                { name: 'Warning/Info/Warning' },
            ],
        };
        expect(createColorGroups(colorObjects)).toEqual(expectedColorMap);
    });
    it('2. should work with empty colorObjects array', () => {
        const colorObjects: any = [];
        const expectedColorMap = {};
        expect(createColorGroups(colorObjects)).toEqual(expectedColorMap);
    });
});

describe('util - createBaseColorsFromGroup', () => {
    // Returns an object with base colors when given an array of color objects
    it('should return an object with base colors when given an array of color objects', () => {
        const colorObjects = sortedLight['Accent-A'];

        const expectedResult = {
            A100: '#14324F',
            A90: '#314E72',
            'A80 (Vera Primary)': '#4D6995',
            A70: '#677FA5',
            A60: '#8196B5',
            'A50 (Brand Primary)': '#9AACC4',
            A40: '#B4C3D4',
            A30: '#CED9E4',
            A20: '#DAE3ED',
            'A10 (Brand Accent)': '#E5EDF6',
        };

        const result = createBaseColorsFromGroup(colorObjects);

        expect(result).toEqual(expectedResult);
    });
});

describe('util - createFromLightDarkBase', () => {
    it('1. should return a palette object by combining keys', () => {
        const base = { C100: '#044F44', C90: '#156B5C' };
        const darkBase = { C100: '#D7E8D2', C90: '#C4D9C0' };
        const result = createFromLightDarkBase(base, darkBase);
        expect(result).toEqual({
            C100: { light: '#044F44', dark: '#D7E8D2' },
            C90: { light: '#156B5C', dark: '#C4D9C0' },
        });
    });
});
