/**
 *  CREATES PALETTE from light base combining
 * D10(Dx) and D100(Dy), such that x + y always equal 110
 * @param base
 * @param initial
 * @returns
 */
export const mixColors = (base: any = {}, initial = '') => {
    const palette: any = {};
    for (let num = 10; num < 101; num += 10) {
        const currentKey = initial + num;
        const complementaryKey = initial + (110 - num);
        palette[currentKey] = {
            light: base[currentKey],
            dark: base[complementaryKey],
        };
    }
    return palette;
};

/**
 * CREATES PALETTE using light and dark base
 * @param base = { C100: '#044F44', ...}
 * @param darkBase = { C100: '#D7E8D2', ...}
 * @returns palette after combining same key colors
 * from base and darkBase
 * {
    C100: {
        light: '#044F44',
        dark: '#D7E8D2',
    }, ...
}
 */
export const createFromLightDarkBase = (base: any = {}, darkBase: any = {}) => {
    const palette: any = {};
    for (let k in base) {
        palette[k] = {
            light: base[k],
            dark: darkBase[k],
        };
    }
    return palette;
};
/**
 * groups colors based on middle group name
 * @param colorObjects
 */
export function createColorGroups(colorObjects: any[]) {
    const colorMap: Record<string, Array<any>> = {};
    for (let colorObject of colorObjects) {
        const colorNames = colorObject.name.split('/');
        const colorGroupKey = colorNames[1];
        if (!colorMap[colorGroupKey]) {
            colorMap[colorGroupKey] = [colorObject];
        } else {
            colorMap[colorGroupKey].push(colorObject);
        }
    }
    return colorMap;
}
/**
 * createBaseColorsFromGroup(sortedLight['Accent-E'])
 * @param ColorObjects
 * @returns  object like
 * const base = {
    C100: '#044F44',
    C90: '#036D5D',
    C80: '#018C77', //  (Text)
    C70: '#00AA90', //  (AP24 Green)
    C60: '#34A997',
    C50: '#68A89E',
    C40: '#9CA7A5', //  (Brand Primary)
    C30: '#C4CAC9',
    C20: '#EBEDED',
    C10: '#E3E5D6', // (Brand Accent)
};
 */
export function createBaseColorsFromGroup(ColorObjects: any[]) {
    const baseColorMap: any = {};
    for (let colorObj of ColorObjects) {
        const colorName = colorObj.name.split('/').at(-1);
        baseColorMap[colorName] = colorObj.value;
    }
    return baseColorMap;
}
